@@ -11,7 +11,10 @@ class Credentials:
         self.url = connection.host
         self.access_key = connection.login
         self.secret_key = connection.password
-        version_check = json.loads(connection.extra)['ENABLE_VERSION_CHECK']
+        if connection.extra is not None and len(connection.extra) > 0:
+            version_check = json.loads(connection.extra)['ENABLE_VERSION_CHECK']
+        else:
+            version_check = True
         if isinstance(version_check, str):
             self.do_version_check = bool(util.strtobool(version_check))
         else:
